/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** No Commercial Usage
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**
**
**
**
**
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QSTILLIMAGECAPTURE_H
#define QSTILLIMAGECAPTURE_H

#include <qmediaobject.h>
#include <qmediaencodersettings.h>

QT_BEGIN_NAMESPACE
class QSize;
QT_END_NAMESPACE

QTM_BEGIN_NAMESPACE

class QImageEncoderSettings;

class QStillImageCapturePrivate;
class Q_MEDIA_EXPORT QStillImageCapture : public QMediaObject
{
    Q_OBJECT
    Q_ENUMS(Error)
    Q_PROPERTY(bool readyForCapture READ isReadyForCapture NOTIFY readyForCaptureChanged)
public:
    enum Error
    {
        NoError,
        NotReadyError,
        ResourceError,
        NotSupportedFeatureError,
        FormatError
    };

    QStillImageCapture(QMediaObject *mediaObject, QObject *parent = 0);
    ~QStillImageCapture();

    bool isAvailable() const;
    QtMedia::AvailabilityError availabilityError() const;

    Error error() const;
    QString errorString() const;

    bool isReadyForCapture() const;

    QStringList supportedImageCodecs() const;
    QString imageCodecDescription(const QString &codecName) const;

    QList<QSize> supportedResolutions(const QImageEncoderSettings &settings = QImageEncoderSettings(),
                                      bool *continuous = 0) const;

    QImageEncoderSettings encodingSettings() const;
    void setEncodingSettings(const QImageEncoderSettings& settings);

public Q_SLOTS:
    void capture(const QString &fileName);

Q_SIGNALS:
    void error(QStillImageCapture::Error error);

    void readyForCaptureChanged(bool);
    void imageCaptured(const QString &fileName, const QImage &preview);
    void imageSaved(const QString &fileName);

private:
    Q_DISABLE_COPY(QStillImageCapture)
    Q_DECLARE_PRIVATE(QStillImageCapture)
    Q_PRIVATE_SLOT(d_func(), void _q_error(int, const QString &))
};

QTM_END_NAMESPACE

Q_DECLARE_METATYPE(QTM_PREPEND_NAMESPACE(QStillImageCapture::Error))

#endif

